@@ -1,35 +1,37 @@
       implicit none
 #include "Zmedia.h"
 #include "Zmass.h"
-c
-c          test Bhabha scattering
-c 
-      record /epmedia/media
+!
+!          test Bhabha scattering
+! 
+       type(epmedia):: media
       integer i, io, icon
       real*8 Ep, prob, Epp, cosp, cose, Ee, w, path
-      character*80 file
+      character*120 file
+      character*12 name
 
       io = 10
       
       call  cerrorMsg(
-     * 'Enter positron energy(1GeV), cutoff kinetic energy(200.d-6 GeV)'//
-     * ' and file path(../../Data/Media/BGO)', 1)
-      file = '../../Data/Media/BGO'
+     * 'Enter positron energy(T.E, 1GeV), cutoff kinetic'//
+     * ' energy(100.d-6 GeV)  and media name(BGO)', 1)
+      name = "W"
       Ep = 1.
-      w = 200.d-6
-      read(*, *) Ep, w, file
-      call cerrorMsg(file,  1)
-
+      w = 100.d-6
+      read(*, *) Ep, w, name
+      call cerrorMsg(name,  1)
+      file = "$EPICSTOP/Data/Media/"//trim(name)
       call copenf(io, file, icon)
       call epReadTab(io, media)
       close(io)
       call epGetEffZA(media)
-      call epStern(w, media)
+      call epStern(media)  !  argument is now 1. 
 
+      write(*,'(a)')
+     * "# prob/r.l sampled:  E+'   E-/E+    cos+   cos-    path(r.l)"
       do i = 1,  100000
          call epbhabhap(media, Ep, w,  prob, path)
          call epbhabhae(Ep, w, Epp, Ee, cosp, cose)
-c         call epbhabhae(Ep,  Epp, Ee, cosp, cose)
          write(*,'(1p,6g12.4)') prob, Epp, (Ee-masele)/(Ep-masele),
      *     cosp, cose, path
       enddo
