@@ -29,7 +29,7 @@
 !                              6)  attn coef. with coh.
 !                              7)  attn coef. without coh.
       Ex = 1.e-6
-      do i = 1,700
+      do while (Ex < 100.d0)
          call cGetXXsec(Ex, media%xcom%tab,
 !     *   media.xcom.size, 7, xsec, icon)
      *   media%xcom%size, 1, 7, xsec, icon)
